A helper to navigate batched results in a web page.

..
    This file is part of lazr.batchnavigator.

    lazr.batchnavigator is free software: you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation, version 3 of the License.

    lazr.batchnavigator is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
    License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with lazr.batchnavigator. If not, see
    <http://www.gnu.org/licenses/>.
